==> owlapi-api-5.0.5-sources.jar: org/semanticweb/owlapi/util/ShortFormProvider.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.util;

import org.semanticweb.owlapi.model.OWLEntity;

/**
 * A short form provider produces renderings of entities. These renderings are
 * strings which in general can be used for display and serialisation purposes.
 * A given entity only has one short form for a given short form provider.
 * However, a short form may map to multiple enntities for a given short form
 * provider. In other words, for a given short form provider the mapping from
 * entity to short form is functional, but is not inverse functional i.e. an
 * injective mapping.
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.0.0
 */
public interface ShortFormProvider {

    /**
     * Gets the short form for the specified entity.
     * 
     * @param entity
     *        The entity.
     * @return A string which represents a short rendering of the specified
     *         entity. The returned value will not be null but might be an empty
     *         string.
     */
    String getShortForm(OWLEntity entity);

    /**
     * Disposes of the short form proivider. This frees any resources and clears
     * any caches.
     */
    default void dispose() {
        // nothing to dispose
    }
}

==> owlapi-api-5.1.11-sources.jar: org/semanticweb/owlapi/util/ShortFormProvider.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.util;

import org.semanticweb.owlapi.model.OWLEntity;

/**
 * A short form provider produces renderings of entities. These renderings are
 * strings which in general can be used for display and serialisation purposes.
 * A given entity only has one short form for a given short form provider.
 * However, a short form may map to multiple enntities for a given short form
 * provider. In other words, for a given short form provider the mapping from
 * entity to short form is functional, but is not inverse functional i.e. an
 * injective mapping.
 *
 * @author Matthew Horridge, The University Of Manchester, Bio-Health Informatics Group
 * @since 2.0.0
 */
public interface ShortFormProvider {

    /**
     * Gets the short form for the specified entity.
     *
     * @param entity The entity.
     * @return A string which represents a short rendering of the specified entity. The returned
     * value will not be null but might be an empty string.
     */
    String getShortForm(OWLEntity entity);

    /**
     * Disposes of the short form proivider. This frees any resources and clears
     * any caches.
     */
    default void dispose() {
        // nothing to dispose
    }
}
